@@ -14,7 +14,13 @@ except ImportError:
 
 import requests
 
-from vdb.lib import CvssV3, Vulnerability, VulnerabilityDetail, VulnerabilitySource
+from vdb.lib import (
+    CvssV3,
+    Vulnerability,
+    VulnerabilityDetail,
+    VulnerabilitySource,
+    CustomNamedTemporaryFile,
+)
 from vdb.lib import config as config
 from vdb.lib import db as dbLib
 
@@ -73,7 +79,7 @@ class NvdSource(VulnerabilitySource):
         """Private Method which downloads the given CVE gzip from NVD"""
         url = config.nvd_url % dict(year=year)
         LOG.debug("Download NVD CVE from {}".format(url))
-        with tempfile.NamedTemporaryFile() as tf:
+        with CustomNamedTemporaryFile() as tf:
             try:
                 r = requests.get(url, stream=True)
             except Exception:
