@@ -36,6 +36,12 @@ BASEVERSION = re.compile(
 
 KNOWN_PRERELEASE_STR = ["final", "release", "alpha", "beta", "rc", "latest"]
 
+DEBIAN_VALID_VERSION = re.compile(
+    r"^((?P<epoch>\d+):)?"
+    "(?P<upstream_version>[A-Za-z0-9.+:~-]+?)"
+    "(-(?P<debian_revision>[A-Za-z0-9+.~]+))?$"
+)
+
 
 class ClassNotFoundError(Exception):
     """docstring for ClassNotFoundError"""
@@ -327,6 +333,15 @@ def checkHex(s):
     return all(c in hex_digits for c in s)
 
 
+def checkEpoch(s):
+    if not s:
+        return False
+    m = DEBIAN_VALID_VERSION.search(s)
+    if not m:
+        return False
+    return True if m.group("epoch") is not None else False
+
+
 def is_hash_mode(
     compare_ver,
     min_version,
@@ -343,6 +358,53 @@ def is_hash_mode(
     )
 
 
+def is_epoch_mode(
+    compare_ver,
+    min_version,
+    max_version,
+    min_affected_version_excluding,
+    max_affected_version_excluding,
+):
+    return (
+        checkEpoch(compare_ver)
+        or checkEpoch(min_version)
+        or checkEpoch(max_version)
+        or checkEpoch(min_affected_version_excluding)
+        or checkEpoch(max_affected_version_excluding)
+    )
+
+
+def trim_epoch(
+    compare_ver,
+    min_version,
+    max_version,
+    min_affected_version_excluding,
+    max_affected_version_excluding,
+):
+    if checkEpoch(compare_ver):
+        m = DEBIAN_VALID_VERSION.search(compare_ver)
+        compare_ver = m.group("upstream_version")
+    if checkEpoch(min_version):
+        m = DEBIAN_VALID_VERSION.search(min_version)
+        min_version = m.group("upstream_version")
+    if checkEpoch(max_version):
+        m = DEBIAN_VALID_VERSION.search(max_version)
+        max_version = m.group("upstream_version")
+    if checkEpoch(min_affected_version_excluding):
+        m = DEBIAN_VALID_VERSION.search(min_affected_version_excluding)
+        min_affected_version_excluding = m.group("upstream_version")
+    if checkEpoch(max_affected_version_excluding):
+        m = DEBIAN_VALID_VERSION.search(max_affected_version_excluding)
+        max_affected_version_excluding = m.group("upstream_version")
+    return (
+        compare_ver,
+        min_version,
+        max_version,
+        min_affected_version_excluding,
+        max_affected_version_excluding,
+    )
+
+
 def version_compare(
     compare_ver,
     min_version,
@@ -368,6 +430,28 @@ def version_compare(
         min_affected_version_excluding,
         max_affected_version_excluding,
     )
+    # Debian OS packages could have epoch. Detect and extract the upstream version
+    epoch_mode_detected = is_epoch_mode(
+        compare_ver,
+        min_version,
+        max_version,
+        min_affected_version_excluding,
+        max_affected_version_excluding,
+    )
+    if epoch_mode_detected:
+        (
+            compare_ver,
+            min_version,
+            max_version,
+            min_affected_version_excluding,
+            max_affected_version_excluding,
+        ) = trim_epoch(
+            compare_ver,
+            min_version,
+            max_version,
+            min_affected_version_excluding,
+            max_affected_version_excluding,
+        )
     # Semver compatible and including versions provided
     is_min_exclude = False
     is_max_exclude = False
